@@ -1,12 +1,12 @@
 library(ggplot2)
-library(dplyr)
+suppressPackageStartupMessages(library(dplyr))
 
 
 # PPV / NPV calculation ---------------------------------------------------
 
 testthat::test_that("Clasical breast cancer problem, hardcoded results", {
   p <- testthat::evaluate_promise(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       min_Prevalence = 1, max_Prevalence = 200,
       Sensitivity = 80, limits_Specificity = c(80, 100),
       overlay = "area",
@@ -15,11 +15,11 @@ testthat::test_that("Clasical breast cancer problem, hardcoded results", {
     )
   )
 
-  p_build <- ggplot2::ggplot_build(p$result)
+  p_build <- ggplot2::ggplot_build(p$result$p)
   PPV_PLOT <-
     as.numeric(gsub(".*: ([0-9]{1,2})%", "\\1", p_build$data[[3]]$label)) / 100
   
-  PPV_tibble <- p$result$data %>%
+  PPV_tibble <- p$result$PPV_melted %>%
     filter(sensitivity == 80 / 100) %>%
     filter(FP == 9.6) %>%
     filter(abs(prevalence_2 - 100) == min(abs(prevalence_2 - 100)))
@@ -56,11 +56,11 @@ testthat::test_that("calculated PPV in area plot", {
     )
   )
 
-  p_build <- ggplot2::ggplot_build(p$result)
+  p_build <- ggplot2::ggplot_build(p$result$p)
   PPV_PLOT <-
     as.numeric(gsub(".*: ([0-9]{1,2})%", "\\1", p_build$data[[3]]$label)) / 100
   
-  PPV_tibble <- p$result$data %>%
+  PPV_tibble <- p$result$PPV_melted %>%
     filter(sensitivity == Sensitivity / 100) %>%
     filter(FP == overlay_position_FP) %>% 
     # Closest prevalence_2
@@ -82,7 +82,7 @@ testthat::test_that("calculated PPV in area plot", {
 
 testthat::test_that("* limits_Specificity needs two different numbers: limits_Specificity = c(min, max)", {
   testthat::expect_error(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       min_Prevalence = 1, max_Prevalence = 1000,
       Sensitivity = 100, limits_Specificity = c(100, 100),
       PPV_NPV = "PPV"
@@ -92,7 +92,7 @@ testthat::test_that("* limits_Specificity needs two different numbers: limits_Sp
 
 testthat::test_that("* limits_Specificity need two different numbers: limits_Specificity = c(min, max)", {
   testthat::expect_error(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       min_Prevalence = 1, max_Prevalence = 1000,
       Sensitivity = 100, Specificity = 100, limits_Specificity = c(100, 100),
       PPV_NPV = "PPV"
@@ -102,7 +102,7 @@ testthat::test_that("* limits_Specificity need two different numbers: limits_Spe
 
 testthat::test_that("* limits_Sensitivity need two different numbers: limits_Sensitivity = c(min, max)", {
   testthat::expect_error(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       min_Prevalence = 1, max_Prevalence = 1000,
       Specificity = 100, limits_Sensitivity = c(100, 100),
       PPV_NPV = "NPV"
@@ -112,7 +112,7 @@ testthat::test_that("* limits_Sensitivity need two different numbers: limits_Sen
 
 testthat::test_that("* limits_Sensitivity need two different numbers: limits_Sensitivity = c(min, max)", {
   testthat::expect_error(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       min_Prevalence = 1, max_Prevalence = 1000,
       Specificity = 100, Sensitivity = 100, limits_Sensitivity = c(100, 100),
       PPV_NPV = "NPV"
@@ -122,7 +122,7 @@ testthat::test_that("* limits_Sensitivity need two different numbers: limits_Sen
 
 testthat::test_that("* limits_Specificity sould be a vector of length 2, now is (90, 90, 100). e.g.: limits_Specificity = c(90, 95)", {
   testthat::expect_error(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       min_Prevalence = 1, max_Prevalence = 1000,
       Sensitivity = 90, limits_Specificity = c(80, 90, 100),
       PPV_NPV = "PPV"
@@ -132,7 +132,7 @@ testthat::test_that("* limits_Specificity sould be a vector of length 2, now is
 
 testthat::test_that("* limits_Sensitivity sould be a vector of length 2, now is (90, 90, 100). e.g.: limits_Sensitivity = c(90, 95)", {
   testthat::expect_error(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       min_Prevalence = 1, max_Prevalence = 1000,
       Specificity = 90, limits_Sensitivity = c(80, 90, 100),
       PPV_NPV = "NPV"
@@ -143,16 +143,16 @@ testthat::test_that("* limits_Sensitivity sould be a vector of length 2, now is
 
 testthat::test_that("ERRORS because of Wrong parameters", {
   testthat::expect_error(testthat::evaluate_promise(
-    BayesianReasoning::PPV_heatmap(Sensitivity = 200, PPV_NPV = "PPV")
+    p <- BayesianReasoning::PPV_heatmap(Sensitivity = 200, PPV_NPV = "PPV")
   )) # * Sensitivity should be a value 0-100
   testthat::expect_error(testthat::evaluate_promise(
-    BayesianReasoning::PPV_heatmap(Specificity = 200, PPV_NPV = "NPV")
+    p <- BayesianReasoning::PPV_heatmap(Specificity = 200, PPV_NPV = "NPV")
   )) # * Specificity should be a value 0-100
   
   # * limits_Specificity sould be a vector of length 2, now is (200). e.g.:
   # limits_Specificity = c(90, 95)
   testthat::expect_error(testthat::evaluate_promise(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       Sensitivity = 95,
       limits_Specificity = 200,
       PPV_NPV = "PPV"
@@ -162,7 +162,7 @@ testthat::test_that("ERRORS because of Wrong parameters", {
   # * limits_Sensitivity sould be a vector of length 2, now is (200). e.g.:
   # limits_Sensitivity = c(90, 95)
   testthat::expect_error(testthat::evaluate_promise(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       Specificity = 95,
       limits_Sensitivity = 200,
       PPV_NPV = "NPV"
@@ -172,7 +172,7 @@ testthat::test_that("ERRORS because of Wrong parameters", {
   # * limits_Specificity should be between 0 and 100, now are (0, 200). e.g.:
   # limits_Specificity = c(90, 95)
   testthat::expect_error(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       Sensitivity = 95,
       limits_Specificity = c(0, 200),
       PPV_NPV = "PPV"
@@ -182,7 +182,7 @@ testthat::test_that("ERRORS because of Wrong parameters", {
   # * limits_Sensitivity should be between 0 and 100, now are (0, 200). e.g.:
   # limits_Sensitivity = c(90, 95)
   testthat::expect_error(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       Specificity = 95,
       limits_Sensitivity = c(0, 200),
       PPV_NPV = "NPV"
@@ -190,17 +190,17 @@ testthat::test_that("ERRORS because of Wrong parameters", {
   ) 
   
   testthat::expect_error(
-    BayesianReasoning::PPV_heatmap(overlay = "area", PPV_NPV = "PPV")
+    p <- BayesianReasoning::PPV_heatmap(overlay = "area", PPV_NPV = "PPV")
     ) # * Sensitivity is needed in PPV_NPV == 'PPV'
   testthat::expect_error(
-    BayesianReasoning::PPV_heatmap(overlay = "area", PPV_NPV = "NPV")
+    p <- BayesianReasoning::PPV_heatmap(overlay = "area", PPV_NPV = "NPV")
     ) # * Specificity is needed in PPV_NPV == 'NPV'
   
   # Missing overlay_prevalence_ parameters
   # * Missing the overlay_prevalence_1 parameter for the overlay's prevalence
   # (overlay_prevalence_1 out of overlay_prevalence_2)
   testthat::expect_error(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       Sensitivity = 99,
       limits_Specificity = c(90, 100),
       overlay = "area",
@@ -214,7 +214,7 @@ testthat::test_that("ERRORS because of Wrong parameters", {
   # * Missing the overlay_prevalence_2 parameter for the overlay's prevalence
   # (overlay_prevalence_1 out of overlay_prevalence_2)
   testthat::expect_error(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       Sensitivity = 99,
       limits_Specificity = c(90, 100),
       overlay = "area",
@@ -229,7 +229,7 @@ testthat::test_that("ERRORS because of Wrong parameters", {
   # overlay_prevalence_2 parameters (overlay_prevalence_1 out of
   # overlay_prevalence_2)
   testthat::expect_error(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       Sensitivity = 99,
       limits_Specificity = c(90, 100),
       overlay = "area",
@@ -238,7 +238,7 @@ testthat::test_that("ERRORS because of Wrong parameters", {
   )
   
   testthat::expect_error(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       Sensitivity = 99,
       limits_Specificity = c(90, 100),
       overlay = "area",
@@ -249,7 +249,7 @@ testthat::test_that("ERRORS because of Wrong parameters", {
   
   # * overlay_position_FN needs a value
   testthat::expect_error(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       Specificity = 99,
       limits_Sensitivity = c(90, 100),
       overlay = "area",
@@ -261,7 +261,7 @@ testthat::test_that("ERRORS because of Wrong parameters", {
   # * Both Specificity (6.5) and limits_Specificity (5, 8) have values. Ignoring
   # Sensitivity and using limits_Specificity
   testthat::expect_warning(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       Sensitivity = 2,
       Specificity = 1,
       limits_Specificity = c(5, 8),
@@ -270,8 +270,8 @@ testthat::test_that("ERRORS because of Wrong parameters", {
   )
   
   # * limits_Specificity is NULL. Setting limits_Specificity = c(-4, 6)
-  testthat::expect_warning(
-    BayesianReasoning::PPV_heatmap(
+  testthat::expect_message(
+    p <- BayesianReasoning::PPV_heatmap(
       Sensitivity = 2,
       Specificity = 1,
       limits_Sensitivity = c(5, 8),
@@ -279,10 +279,10 @@ testthat::test_that("ERRORS because of Wrong parameters", {
     )
   ) 
   
-  # * limits_Sensitivity is NULL. Setting limits_Sensitivity = c(-3, 7)
-  testthat::expect_warning(
-    BayesianReasoning::PPV_heatmap(
-      Sensitivity = 2,
+  # No message expected
+  testthat::expect_no_message(
+    p <- BayesianReasoning::PPV_heatmap(
+      Sensitivity = 2, 
       Specificity = 1,
       limits_Specificity = c(5, 8),
       PPV_NPV = "NPV"
@@ -292,7 +292,7 @@ testthat::test_that("ERRORS because of Wrong parameters", {
   # * Both Sensitivity (2) and limits_Sensitivity (5, 8) have values. Ignoring
   # Sensitivity and using limits_Sensitivity
   testthat::expect_warning(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       Sensitivity = 2,
       Specificity = 1,
       limits_Sensitivity = c(5, 8),
@@ -303,7 +303,7 @@ testthat::test_that("ERRORS because of Wrong parameters", {
   # * overlay_prevalence_1 has > 1 value. Not allowed in overlay = 'area'. Did
   # you meant overlay = 'line'?
   testthat::expect_error(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       Sensitivity = 99,
       limits_Specificity = c(90, 100),
       overlay = "area",
@@ -316,7 +316,7 @@ testthat::test_that("ERRORS because of Wrong parameters", {
   # * overlay_position_FP has > 1 value. Not allowed in overlay = 'area'. Did
   # you meant overlay = 'line'?
   testthat::expect_error(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       Sensitivity = 99,
       limits_Specificity = c(90, 100),
       overlay = "area",
@@ -330,7 +330,7 @@ testthat::test_that("ERRORS because of Wrong parameters", {
   # * overlay_position_FN has > 1 value. Not allowed in overlay = 'area'. Did
   # you meant overlay = 'line'?
   testthat::expect_error(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       Specificity = 99,
       limits_Sensitivity = c(90, 100),
       overlay = "area",
@@ -346,7 +346,7 @@ testthat::test_that("ERRORS because of Wrong parameters", {
 
 testthat::test_that("WARNINGS because of Wrong parameters", {
   testthat::expect_warning(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       Sensitivity = 99,
       limits_Specificity = c(90, 100),
       overlay = "area",
@@ -357,7 +357,7 @@ testthat::test_that("WARNINGS because of Wrong parameters", {
     )
   ) # [WARNING]: overlay_position_FP (90) is > than max_FP (10).
   testthat::expect_warning(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       Specificity = 99,
       limits_Sensitivity = c(90, 100),
       overlay = "area",
@@ -369,7 +369,7 @@ testthat::test_that("WARNINGS because of Wrong parameters", {
   ) # [WARNING]: overlay_position_FN (90) is > max_FN (10)
   
   testthat::expect_warning(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       Specificity = 99,
       limits_Sensitivity = c(90, 100),
       overlay = "area",
@@ -384,7 +384,7 @@ testthat::test_that("WARNINGS because of Wrong parameters", {
   
   res1 <-
     testthat::evaluate_promise(
-      BayesianReasoning::PPV_heatmap(
+      p <- BayesianReasoning::PPV_heatmap(
         Sensitivity = 99,
         limits_Specificity = c(90, 100),
         overlay = "area",
@@ -401,7 +401,7 @@ testthat::test_that("WARNINGS because of Wrong parameters", {
   
   res2 <-
     testthat::evaluate_promise(
-      BayesianReasoning::PPV_heatmap(
+      p <- BayesianReasoning::PPV_heatmap(
         Specificity = 99,
         limits_Sensitivity = c(90, 100),
         overlay = "area",
@@ -432,7 +432,7 @@ testthat::test_that("WARNINGS because of Wrong parameters", {
   
   res4 <-
     testthat::evaluate_promise(
-      BayesianReasoning::PPV_heatmap(
+      p <- BayesianReasoning::PPV_heatmap(
         Sensitivity = 99,
         limits_Specificity = c(90, 100),
         overlay = "line",
@@ -460,7 +460,7 @@ testthat::test_that("WARNINGS because of Wrong parameters", {
   
   res5 <-
     testthat::evaluate_promise(
-      BayesianReasoning::PPV_heatmap(
+      p <- BayesianReasoning::PPV_heatmap(
         Sensitivity = 99,
         limits_Specificity = c(90, 100),
         overlay = "area",
@@ -482,7 +482,7 @@ testthat::test_that("WARNINGS because of Wrong parameters", {
 
 testthat::test_that("WARNING min_Prevalence > max_Prevalence", {
   res <- testthat::evaluate_promise(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       min_Prevalence = 2000,
       max_Prevalence = 1000,
       Sensitivity = 81,
@@ -503,7 +503,7 @@ testthat::test_that("WARNING min_Prevalence > max_Prevalence", {
 
 testthat::test_that("WARNING overlay_prevalence_1/overlay_prevalence_2", {
   res <- testthat::evaluate_promise(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       min_Prevalence = 2,
       max_Prevalence = 1000,
       Sensitivity = 81,
@@ -528,7 +528,7 @@ testthat::test_that("WARNING overlay_prevalence_1/overlay_prevalence_2", {
 
 testthat::test_that("WARNINGS overlay_position_FP, overlay_prevalence_2", {
   res <- testthat::evaluate_promise(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       min_Prevalence = 2,
       max_Prevalence = 1000,
       Sensitivity = 81,
@@ -553,7 +553,7 @@ testthat::test_that("WARNINGS overlay_position_FP, overlay_prevalence_2", {
 
 testthat::test_that("WARNINGS - NPV", {
   res <- testthat::evaluate_promise(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       PPV_NPV = "NPV",
       DEBUG = 1,
       min_Prevalence = 2,
@@ -583,14 +583,14 @@ testthat::test_that("WARNINGS - NPV", {
 
 testthat::test_that("Extra decimals when axis are tight", {
   p <- testthat::evaluate_promise(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       min_Prevalence = 1, max_Prevalence = 1.1,
       Sensitivity = 100, limits_Specificity = c(99.9, 100)
     )
   )
 
   testthat::expect_equal(
-    p$result$plot_env$breaks_x,
+    p$result$p$plot_env$breaks_x,
     c(0.00, 0.01, 0.02, 0.03, 0.04, 0.05, 0.06, 0.07, 0.08, 0.09, 0.10)
   )
 })
@@ -598,7 +598,7 @@ testthat::test_that("Extra decimals when axis are tight", {
 
 testthat::test_that("PPV Plot", {
   p <- testthat::evaluate_promise(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       min_Prevalence = 1,
       max_Prevalence = 1000,
       Sensitivity = 100,
@@ -610,14 +610,14 @@ testthat::test_that("PPV Plot", {
     )
   )
 
-  testthat::expect_true(ggplot2::is.ggplot(p$result))
-  testthat::expect_identical(p$result$labels$x, "False + (1 - Specificity)")
-  testthat::expect_identical(p$result$labels$y, "Prevalence")
-  testthat::expect_identical(p$result$labels$title, "Title plot")
-  testthat::expect_identical(p$result$labels$subtitle, "Subtitle plot")
-  testthat::expect_identical(p$result$labels$caption, "Sensitivity = 100%")
+  testthat::expect_true(ggplot2::is_ggplot(p$result$p))
+  testthat::expect_identical(p$result$p$labels$x, "False + (1 - Specificity)")
+  testthat::expect_identical(p$result$p$labels$y, "Prevalence")
+  testthat::expect_identical(p$result$p$labels$title, "Title plot")
+  testthat::expect_identical(p$result$p$labels$subtitle, "Subtitle plot")
+  testthat::expect_identical(p$result$p$labels$caption, "Sensitivity = 100%")
   testthat::expect_equal(
-    p$result$plot_env$breaks_y,
+    p$result$p$plot_env$breaks_y,
     c(
       0.001000000,
       0.002154435,
@@ -632,10 +632,10 @@ testthat::test_that("PPV Plot", {
     )
   )
   testthat::expect_equal(
-    p$result$plot_env$breaks_x,
+    p$result$p$plot_env$breaks_x,
     c(0.0, 0.5, 1.0, 1.5, 2.0, 2.5, 3.0, 3.5, 4.0, 4.5, 5.0))
   testthat::expect_equal(
-    p$result$plot_env$labels_x,
+    p$result$p$plot_env$labels_x,
     c(
       "0%",
       "0.5%",
@@ -651,7 +651,7 @@ testthat::test_that("PPV Plot", {
     )
   )
   testthat::expect_equal(
-    p$result$plot_env$labels_y,
+    p$result$p$plot_env$labels_y,
     c(
       "1 out of 1000",
       "2 out of 1000",
@@ -665,18 +665,18 @@ testthat::test_that("PPV Plot", {
       "1000 out of 1000"
     )
   )
-  testthat::expect_equal(p$result$plot_env$breaks_legend,
+  testthat::expect_equal(p$result$p$plot_env$breaks_legend,
                          c(0.00, 0.25, 0.50, 0.75, 1.00))
-  testthat::expect_identical(p$result$labels$fill, "PPV")
-  testthat::expect_equal(length(p$result$plot_env$max_FP), 1)
-  testthat::expect_equal(p$result$plot_env$max_FP, 5)
-  testthat::expect_equal(length(p$result$plot_env$max_FN), 0)
+  # testthat::expect_identical(p$result$p$labels$fill, NULL)
+  testthat::expect_equal(length(p$result$p$plot_env$max_FP), 1)
+  testthat::expect_equal(p$result$p$plot_env$max_FP, 5)
+  testthat::expect_equal(length(p$result$p$plot_env$max_FN), 0)
 })
 
 
 testthat::test_that("NPV Plot", {
   p <- testthat::evaluate_promise(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       min_Prevalence = 1,
       max_Prevalence = 1000,
       Specificity = 100,
@@ -687,14 +687,14 @@ testthat::test_that("NPV Plot", {
       PPV_NPV = "NPV"
     )
   )
-  testthat::expect_true(ggplot2::is.ggplot(p$result))
-  testthat::expect_identical(p$result$labels$x, "False - (1 - Sensitivity)")
-  testthat::expect_identical(p$result$labels$y, "Prevalence")
-  testthat::expect_identical(p$result$labels$title, "Title plot")
-  testthat::expect_identical(p$result$labels$subtitle, "Subtitle plot")
-  testthat::expect_identical(p$result$labels$caption, "Specificity = 100%")
+  testthat::expect_true(ggplot2::is_ggplot(p$result$p))
+  testthat::expect_identical(p$result$p$labels$x, "False - (1 - Sensitivity)")
+  testthat::expect_identical(p$result$p$labels$y, "Prevalence")
+  testthat::expect_identical(p$result$p$labels$title, "Title plot")
+  testthat::expect_identical(p$result$p$labels$subtitle, "Subtitle plot")
+  testthat::expect_identical(p$result$p$labels$caption, "Specificity = 100%")
   testthat::expect_equal(
-    p$result$plot_env$breaks_y,
+    p$result$p$plot_env$breaks_y,
     c(
       0.001000000,
       0.002154435,
@@ -709,11 +709,11 @@ testthat::test_that("NPV Plot", {
     )
   )
   testthat::expect_equal(
-    p$result$plot_env$breaks_x,
+    p$result$p$plot_env$breaks_x,
     c(0.0, 0.5, 1.0, 1.5, 2.0, 2.5, 3.0, 3.5, 4.0, 4.5, 5.0)
     )
   testthat::expect_equal(
-    p$result$plot_env$labels_x,
+    p$result$p$plot_env$labels_x,
     c(
       "0%",
       "0.5%",
@@ -729,7 +729,7 @@ testthat::test_that("NPV Plot", {
     )
   )
   testthat::expect_equal(
-    p$result$plot_env$labels_y,
+    p$result$p$plot_env$labels_y,
     c(
       "1 out of 1000",
       "2 out of 1000",
@@ -743,12 +743,12 @@ testthat::test_that("NPV Plot", {
       "1000 out of 1000"
     )
   )
-  testthat::expect_equal(p$result$plot_env$breaks_legend,
+  testthat::expect_equal(p$result$p$plot_env$breaks_legend,
                          c(0.00, 0.25, 0.50, 0.75, 1.00))
-  testthat::expect_identical(p$result$labels$fill, "NPV")
-  testthat::expect_equal(length(p$result$plot_env$max_FP), 0)
-  testthat::expect_equal(length(p$result$plot_env$max_FN), 1)
-  testthat::expect_equal(p$result$plot_env$max_FN, 5)
+  # testthat::expect_identical(p$result$p$labels$fill, NULL)
+  testthat::expect_equal(length(p$result$p$plot_env$max_FP), 0)
+  testthat::expect_equal(length(p$result$p$plot_env$max_FN), 1)
+  testthat::expect_equal(p$result$p$plot_env$max_FN, 5)
 })
 
 
@@ -764,11 +764,11 @@ testthat::test_that("Spanish translation", {
     Language = "sp"
   )
 
-  testthat::expect_identical(p$labels$y, "Prevalencia")
-  testthat::expect_identical(p$labels$x, "Falsos + (1 - Especificidad)")
+  testthat::expect_identical(p$p$labels$y, "Prevalencia")
+  testthat::expect_identical(p$p$labels$x, "Falsos + (1 - Especificidad)")
 
   p <- testthat::evaluate_promise(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       min_Prevalence = 1,
       max_Prevalence = 1000,
       Sensitivity = 100,
@@ -783,16 +783,16 @@ testthat::test_that("Spanish translation", {
     )
   )
 
-  testthat::expect_identical(
-    vapply(p$result$layers, function(x)
-      class(x$geom)[1], ""),
-    c("GeomTile", "GeomPoint", "GeomMarkRect")
-  )
-  testthat::expect_identical(p$result$labels$title, "Title plot")
-  testthat::expect_identical(p$result$labels$subtitle, "Subtitle plot")
+  # testthat::expect_identical(
+  #   vapply(p$result$p$layers, function(x)
+  #     class(x$geom)[1], ""),
+  #   c("geom_tile" = "GeomTile", "annotate" = "GeomPoint", "geom_mark_rect" = "GeomMarkRect")
+  # )
+  testthat::expect_identical(p$result$p$labels$title, "Title plot")
+  testthat::expect_identical(p$result$p$labels$subtitle, "Subtitle plot")
   
   p <- testthat::evaluate_promise(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       PPV_NPV = "NPV",
       min_Prevalence = 1,
       max_Prevalence = 1000,
@@ -805,19 +805,19 @@ testthat::test_that("Spanish translation", {
       overlay_prevalence_2 = 100
     )
   )
-  testthat::expect_identical(
-    vapply(p$result$layers, function(x)
-      class(x$geom)[1], ""),
-    c("GeomTile", "GeomPoint", "GeomMarkRect")
-  )
-  testthat::expect_identical(p$result$labels$y, "Prevalencia")
-  testthat::expect_identical(p$result$labels$x, "Falsos - (1 - Sensibilidad)")
+  # testthat::expect_identical(
+  #   vapply(p$result$p$layers, function(x)
+  #     class(x$geom)[1], ""),
+  #   c("geom_tile" = "GeomTile", "annotate" = "GeomPoint", "geom_mark_rect" = "GeomMarkRect")
+  # )
+  testthat::expect_identical(p$result$p$labels$y, "Prevalencia")
+  testthat::expect_identical(p$result$p$labels$x, "Falsos - (1 - Sensibilidad)")
 })
 
 
 testthat::test_that("one_out_of PPV", {
   p <- testthat::evaluate_promise(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       min_Prevalence = 1, max_Prevalence = 2,
       Sensitivity = 3,
       Specificity = 1,
@@ -829,8 +829,8 @@ testthat::test_that("one_out_of PPV", {
     )
   )
 
-  testthat::expect_true(p$result$plot_env$one_out_of)
-  testthat::expect_equal(range(p$result$plot_env$breaks_x), c(0, 100))
+  testthat::expect_true(p$result$p$plot_env$one_out_of)
+  testthat::expect_equal(range(p$result$p$plot_env$breaks_x), c(0, 100))
 
   p <- testthat::evaluate_promise(
     BayesianReasoning::PPV_heatmap(
@@ -845,7 +845,7 @@ testthat::test_that("one_out_of PPV", {
     )
   )
 
-  testthat::expect_true(p$result$plot_env$one_out_of)
+  testthat::expect_true(p$result$p$plot_env$one_out_of)
 })
 
 
@@ -863,13 +863,13 @@ testthat::test_that("Area overlay, low uncertainty, and decimals in y axis. over
 
   # Overlay description
   testthat::expect_identical(
-    p$layers[[3]]$computed_geom_params$description,
+    p$p$layers[[3]]$computed_geom_params$description,
     "40 y.o.\nPrevalence: 2 out of 8\nSensitivity: 81%\nFalse +: 4.8% \n ---------------------------------------------\n2 sick: 1.62 (+) 0.38 (-)\n6 healthy: 5.71 (-) 0.29 (+) "
   )
   
   # Decimal breaks y axis
   testthat::expect_equal(
-    p$plot_env$breaks_y,
+    p$p$plot_env$breaks_y,
     c(
       0.1250000,
       0.1450162,
@@ -902,13 +902,13 @@ testthat::test_that("Area overlay, low uncertainty, and decimals in y axis. over
 
   # Overlay description
   testthat::expect_identical(
-    p$layers[[3]]$computed_geom_params$description,
+    p$p$layers[[3]]$computed_geom_params$description,
     "40 y.o.\nPrevalence: 2 out of 8\nSensitivity: 81%\nFalse +: 4.8% "
   )
   
   # Decimal breaks y axis
   testthat::expect_equal(
-    p$plot_env$breaks_y,
+    p$p$plot_env$breaks_y,
     c(
       0.1250000,
       0.1450162,
@@ -942,7 +942,7 @@ testthat::test_that("Range of data is the same as the x axis range", {
 
   # Decimal breaks y axis
   testthat::expect_identical(
-    c(p$plot_env$min_FN, p$plot_env$max_FN), range(p$data$FN)
+    c(p$p$plot_env$min_FN, p$p$plot_env$max_FN), range(p$PPV_melted$FN)
     )
 })
 
@@ -950,7 +950,7 @@ testthat::test_that("Range of data is the same as the x axis range", {
 # TODO: Should check uncertainty_prevalence consequences
 testthat::test_that("NPV calculation with area overlay and low uncertainty", {
   p <- testthat::evaluate_promise(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       min_Prevalence = 1, max_Prevalence = 1200,
       limits_Sensitivity = c(76, 86),
       Specificity = 95,
@@ -965,7 +965,7 @@ testthat::test_that("NPV calculation with area overlay and low uncertainty", {
   )
 
   testthat::expect_identical(
-    p$result$layers[[3]]$computed_geom_params$description,
+    p$result$p$layers[[3]]$computed_geom_params$description,
     "40 y.o.\nPrevalence: 67 out of 68\nSpecificity: 95%\nFalse -: 4.8%\n ---------------------------------------------\n67 sick: 63.78 (+) 3.22 (-)\n1 healthy: 0.95 (-) 0.05 (+) "
   )
 })
@@ -973,7 +973,7 @@ testthat::test_that("NPV calculation with area overlay and low uncertainty", {
 
 testthat::test_that("all parameters", {
   testthat::expect_warning(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       min_Prevalence = 1, max_Prevalence = 2,
       Sensitivity = 3,
       Specificity = 99,
@@ -987,7 +987,7 @@ testthat::test_that("all parameters", {
   )
 
   testthat::expect_warning(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       min_Prevalence = 1, max_Prevalence = 100,
       Specificity = 3,
       Sensitivity = 90,
@@ -1009,7 +1009,7 @@ testthat::test_that("all parameters", {
 # ggforce anchor x0
 # https://github.com/thomasp85/ggforce/issues/209
 p <- testthat::evaluate_promise(
-  BayesianReasoning::PPV_heatmap(Min_Prevalence = 1, Max_Prevalence = 1200, Sensitivity = 81, limits_Specificity = c(0, 100),
+  p <- BayesianReasoning::PPV_heatmap(Min_Prevalence = 1, Max_Prevalence = 1200, Sensitivity = 81, limits_Specificity = c(0, 100),
                                  label_subtitle = "Prenatal screening for Down Syndrome by Age",
                                  overlay = "line",
                                  overlay_labels = c("40 y.o.", "35 y.o."),
@@ -1025,7 +1025,7 @@ testthat::expect_equal(p$messages, expected = "ℹ Label/s outside range, will a
 
 testthat::test_that("Plot with line overlay", {
   p <- testthat::evaluate_promise(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       min_Prevalence = 1, max_Prevalence = 1800,
       Sensitivity = 90,
       limits_Specificity = c(84, 100),
@@ -1040,7 +1040,7 @@ testthat::test_that("Plot with line overlay", {
   testthat::expect_length(p$warnings, 0)
 
   p <- testthat::evaluate_promise(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       min_Prevalence = 1, max_Prevalence = 1800,
       Sensitivity = 90, limits_Specificity = c(80, 90),
       label_title = "Title plot",
@@ -1059,16 +1059,16 @@ testthat::test_that("Plot with line overlay", {
       overlay_prevalence_2 = c(22, 26, 29, 44, 69, 227, 1667)
     )
   )
-  testthat::expect_identical(
-    vapply(p$result$layers, function(x)
-      class(x$geom)[1], ""),
-    c("GeomTile", "GeomSegment", "GeomPoint", "GeomMarkRect")
-  )
-  testthat::expect_identical(p$result$labels$title, "Title plot")
-  testthat::expect_identical(p$result$labels$subtitle, "Subtitle plot")
+  # testthat::expect_identical(
+  #   vapply(p$result$p$layers, function(x)
+  #     class(x$geom)[1], ""),
+  #   c("geom_tile" = "GeomTile", "annotate" = "GeomSegment",  "annotate...3" = "GeomPoint", "geom_mark_rect" = "GeomMarkRect")
+  # )
+  testthat::expect_identical(p$result$p$labels$title, "Title plot")
+  testthat::expect_identical(p$result$p$labels$subtitle, "Subtitle plot")
 
   p <- testthat::evaluate_promise(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       PPV_NPV = "NPV",
       uncertainty_prevalence = "high",
       min_Prevalence = 1,
@@ -1094,19 +1094,19 @@ testthat::test_that("Plot with line overlay", {
     )
   )
 
-  testthat::expect_identical(
-    vapply(p$result$layers, function(x)
-      class(x$geom)[1], ""),
-    c("GeomTile", "GeomSegment", "GeomPoint", "GeomMarkRect")
-  )
-  testthat::expect_identical(p$result$labels$title, "Title plot")
-  testthat::expect_identical(p$result$labels$subtitle, "Subtitle plot")
+  # testthat::expect_identical(
+  #   vapply(p$result$p$layers, function(x)
+  #     class(x$geom)[1], ""),
+  #   c("geom_tile" = "GeomTile", "annotate" = "GeomSegment",  "annotate...3" = "GeomPoint", "geom_mark_rect" = "GeomMarkRect")
+  # )
+  testthat::expect_identical(p$result$p$labels$title, "Title plot")
+  testthat::expect_identical(p$result$p$labels$subtitle, "Subtitle plot")
 })
 
 
 testthat::test_that("Unequal overlay number of parameters", {
   testthat::expect_error(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       PPV_NPV = "NPV",
       min_Prevalence = 1, max_Prevalence = 1800,
       Specificity = 85, limits_Sensitivity = c(85, 95),
@@ -1119,7 +1119,7 @@ testthat::test_that("Unequal overlay number of parameters", {
   )
 
   testthat::expect_error(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       PPV_NPV = "PPV",
       min_Prevalence = 1, max_Prevalence = 1800,
       Sensitivity = 85, limits_Specificity = c(85, 95),
@@ -1132,7 +1132,7 @@ testthat::test_that("Unequal overlay number of parameters", {
   )
 
   testthat::expect_error(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       PPV_NPV = "NPV",
       min_Prevalence = 1, max_Prevalence = 1800,
       Specificity = 85, limits_Sensitivity = c(85, 95),
@@ -1166,7 +1166,7 @@ testthat::test_that("Unequal overlay number of parameters", {
 
   # TODO: accept NULL values in overlay line?
   testthat::expect_error(
-    BayesianReasoning::PPV_heatmap(
+    p <- BayesianReasoning::PPV_heatmap(
       min_Prevalence = 1, max_Prevalence = 1200,
       limits_Specificity = c(76, 86),
       Sensitivity = 95,
@@ -1186,30 +1186,30 @@ testthat::test_that("Unequal overlay number of parameters", {
 # Save plot ---------------------------------------------------------------
 
 testthat::test_that("Save plots", {
-  p <- BayesianReasoning::PPV_heatmap(
+  suppressMessages(p <- BayesianReasoning::PPV_heatmap(
     min_Prevalence = 1, max_Prevalence = 1000,
     Sensitivity = 100,
     limits_Specificity = c(90, 100),
     folder = "."
-  )
+  ))
 
   file_name_test <- "PPV_1_1000_100_0_10_en.png"
   testthat::expect_true(file.exists(file_name_test))
   file.remove(file_name_test)
 
-  p <- BayesianReasoning::PPV_heatmap(
+  suppressMessages(p <- BayesianReasoning::PPV_heatmap(
     PPV_NPV = "NPV",
     min_Prevalence = 1, max_Prevalence = 1000,
     Specificity = 100,
     limits_Sensitivity = c(90, 100),
     folder = "."
-  )
+  ))
 
   file_name_test <- "NPV_1_1000_100_0_10_en.png"
   testthat::expect_true(file.exists(file_name_test))
   file.remove(file_name_test)
 
-  p <- BayesianReasoning::PPV_heatmap(
+  suppressMessages(p <- BayesianReasoning::PPV_heatmap(
     PPV_NPV = "NPV",
     min_Prevalence = 1, max_Prevalence = 1000,
     Specificity = 100,
@@ -1220,9 +1220,10 @@ testthat::test_that("Save plots", {
     overlay_prevalence_1 = 1,
     overlay_prevalence_2 = 10,
     folder = "."
-  )
+  ))
 
   file_name_test <- "NPV_1_1000_100_0_10_area_TRUE_en.png"
   testthat::expect_true(file.exists(file_name_test))
   file.remove(file_name_test)
 })
+
